==> runtime-tools-quarkus-extension-deployment-1.41.0.Final.jar: dev-static/webapp/channel/ProcessDetails/ProcessDetailsQueries.d.ts <==
import { ApolloClient } from 'apollo-client';
import { ProcessInstance, Job, JobCancel, TriggerableNode, NodeInstance, SvgSuccessResponse, SvgErrorResponse } from '@kogito-apps/management-console-shared';
export interface ProcessDetailsQueries {
    getProcessDetails(id: string): Promise<ProcessInstance>;
    getJobs(id: string): Promise<Job[]>;
    handleProcessSkip(processInstance: ProcessInstance): Promise<void>;
    handleProcessAbort(processInstance: ProcessInstance): Promise<void>;
    handleProcessRetry(processInstance: ProcessInstance): Promise<void>;
    getSVG(processInstance: ProcessInstance): Promise<any>;
    jobCancel(job: Job): Promise<JobCancel>;
    rescheduleJob: (job: any, repeatInterval: number | string, repeatLimit: number | string, scheduleDate: Date) => Promise<{
        modalTitle: string;
        modalContent: string;
    }>;
    getTriggerableNodes(processInstance: ProcessInstance): Promise<TriggerableNode[]>;
    handleNodeTrigger(processInstance: ProcessInstance, node: any): Promise<void>;
    handleProcessVariableUpdate: (processInstance: ProcessInstance, updateJson: Record<string, unknown>) => Promise<Record<string, unknown>>;
    handleNodeInstanceCancel: (processInstance: ProcessInstance, node: NodeInstance) => Promise<void>;
    handleNodeInstanceRetrigger(processInstance: ProcessInstance, node: NodeInstance): Promise<void>;
}
export declare class GraphQLProcessDetailsQueries implements ProcessDetailsQueries {
    private readonly client;
    constructor(client: ApolloClient<any>);
    getProcessDetails(id: string): Promise<ProcessInstance>;
    getJobs(id: string): Promise<Job[]>;
    handleProcessSkip(processInstance: ProcessInstance): Promise<void>;
    handleProcessAbort(processInstance: ProcessInstance): Promise<void>;
    handleProcessRetry(processInstance: ProcessInstance): Promise<void>;
    getSVG(processInstance: ProcessInstance): Promise<SvgSuccessResponse | SvgErrorResponse>;
    jobCancel(job: Job): Promise<JobCancel>;
    rescheduleJob(job: any, repeatInterval: number | string, repeatLimit: number | string, scheduleDate: Date): Promise<{
        modalTitle: string;
        modalContent: string;
    }>;
    getTriggerableNodes(processInstance: ProcessInstance): Promise<TriggerableNode[]>;
    handleNodeTrigger(processInstance: ProcessInstance, node: any): Promise<void>;
    handleNodeInstanceCancel(processInstance: ProcessInstance, node: NodeInstance): Promise<void>;
    handleProcessVariableUpdate(processInstance: ProcessInstance, updateJson: Record<string, unknown>): Promise<Record<string, unknown>>;
    handleNodeInstanceRetrigger(processInstance: ProcessInstance, node: NodeInstance): Promise<void>;
}

==> runtime-tools-quarkus-extension-deployment-1.44.1.Final.jar: dev-static/webapp/channel/ProcessDetails/ProcessDetailsQueries.d.ts <==
import { ApolloClient } from 'apollo-client';
import { ProcessInstance, Job, JobCancel, TriggerableNode, NodeInstance, SvgSuccessResponse, SvgErrorResponse } from '@kogito-apps/management-console-shared/dist/types';
export interface ProcessDetailsQueries {
    getProcessDetails(id: string): Promise<ProcessInstance>;
    getJobs(id: string): Promise<Job[]>;
    handleProcessSkip(processInstance: ProcessInstance): Promise<void>;
    handleProcessAbort(processInstance: ProcessInstance): Promise<void>;
    handleProcessRetry(processInstance: ProcessInstance): Promise<void>;
    getSVG(processInstance: ProcessInstance): Promise<any>;
    jobCancel(job: Job): Promise<JobCancel>;
    rescheduleJob: (job: any, repeatInterval: number | string, repeatLimit: number | string, scheduleDate: Date) => Promise<{
        modalTitle: string;
        modalContent: string;
    }>;
    getTriggerableNodes(processInstance: ProcessInstance): Promise<TriggerableNode[]>;
    handleNodeTrigger(processInstance: ProcessInstance, node: any): Promise<void>;
    handleProcessVariableUpdate: (processInstance: ProcessInstance, updateJson: Record<string, unknown>) => Promise<Record<string, unknown>>;
    handleNodeInstanceCancel: (processInstance: ProcessInstance, node: NodeInstance) => Promise<void>;
    handleNodeInstanceRetrigger(processInstance: ProcessInstance, node: NodeInstance): Promise<void>;
}
export declare class GraphQLProcessDetailsQueries implements ProcessDetailsQueries {
    private readonly client;
    constructor(client: ApolloClient<any>);
    getProcessDetails(id: string): Promise<ProcessInstance>;
    getJobs(id: string): Promise<Job[]>;
    handleProcessSkip(processInstance: ProcessInstance): Promise<void>;
    handleProcessAbort(processInstance: ProcessInstance): Promise<void>;
    handleProcessRetry(processInstance: ProcessInstance): Promise<void>;
    getSVG(processInstance: ProcessInstance): Promise<SvgSuccessResponse | SvgErrorResponse>;
    jobCancel(job: Job): Promise<JobCancel>;
    rescheduleJob(job: any, repeatInterval: number | string, repeatLimit: number | string, scheduleDate: Date): Promise<{
        modalTitle: string;
        modalContent: string;
    }>;
    getTriggerableNodes(processInstance: ProcessInstance): Promise<TriggerableNode[]>;
    handleNodeTrigger(processInstance: ProcessInstance, node: any): Promise<void>;
    handleNodeInstanceCancel(processInstance: ProcessInstance, node: NodeInstance): Promise<void>;
    handleProcessVariableUpdate(processInstance: ProcessInstance, updateJson: Record<string, unknown>): Promise<Record<string, unknown>>;
    handleNodeInstanceRetrigger(processInstance: ProcessInstance, node: NodeInstance): Promise<void>;
}
